compile_and_test

Function compile_and_test 

fn compile_and_test(
    config: &Arc<Config>,
    evm_opts: &EvmOpts,
    filter_args: &FilterArgs,
    selected_sources_relative: &[PathBuf],
    isolate: bool,
) -> Result<bool>
Compile the project and run tests, returning true if any test failed (mutant killed).

Dispatches to the correct network type based on evm_opts.networks.